@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs.html)
 
 Usage::
 
@@ -52,45 +52,30 @@ __all__ = (
 BlockTypeDef = TypedDict(
     "BlockTypeDef",
     {
-        "BlockIndex": int,
-        "BlockToken": str,
+        "BlockIndex": NotRequired[int],
+        "BlockToken": NotRequired[str],
     },
-    total=False,
 )
 
 ChangedBlockTypeDef = TypedDict(
     "ChangedBlockTypeDef",
     {
-        "BlockIndex": int,
-        "FirstBlockToken": str,
-        "SecondBlockToken": str,
+        "BlockIndex": NotRequired[int],
+        "FirstBlockToken": NotRequired[str],
+        "SecondBlockToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCompleteSnapshotRequestRequestTypeDef = TypedDict(
-    "_RequiredCompleteSnapshotRequestRequestTypeDef",
+CompleteSnapshotRequestRequestTypeDef = TypedDict(
+    "CompleteSnapshotRequestRequestTypeDef",
     {
         "SnapshotId": str,
         "ChangedBlocksCount": int,
+        "Checksum": NotRequired[str],
+        "ChecksumAlgorithm": NotRequired[Literal["SHA256"]],
+        "ChecksumAggregationMethod": NotRequired[Literal["LINEAR"]],
     },
 )
-_OptionalCompleteSnapshotRequestRequestTypeDef = TypedDict(
-    "_OptionalCompleteSnapshotRequestRequestTypeDef",
-    {
-        "Checksum": str,
-        "ChecksumAlgorithm": Literal["SHA256"],
-        "ChecksumAggregationMethod": Literal["LINEAR"],
-    },
-    total=False,
-)
-
-
-class CompleteSnapshotRequestRequestTypeDef(
-    _RequiredCompleteSnapshotRequestRequestTypeDef, _OptionalCompleteSnapshotRequestRequestTypeDef
-):
-    pass
-
 
 CompleteSnapshotResponseTypeDef = TypedDict(
     "CompleteSnapshotResponseTypeDef",
@@ -120,29 +105,16 @@ GetSnapshotBlockResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChangedBlocksRequestRequestTypeDef = TypedDict(
-    "_RequiredListChangedBlocksRequestRequestTypeDef",
+ListChangedBlocksRequestRequestTypeDef = TypedDict(
+    "ListChangedBlocksRequestRequestTypeDef",
     {
         "SecondSnapshotId": str,
+        "FirstSnapshotId": NotRequired[str],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "StartingBlockIndex": NotRequired[int],
     },
 )
-_OptionalListChangedBlocksRequestRequestTypeDef = TypedDict(
-    "_OptionalListChangedBlocksRequestRequestTypeDef",
-    {
-        "FirstSnapshotId": str,
-        "NextToken": str,
-        "MaxResults": int,
-        "StartingBlockIndex": int,
-    },
-    total=False,
-)
-
-
-class ListChangedBlocksRequestRequestTypeDef(
-    _RequiredListChangedBlocksRequestRequestTypeDef, _OptionalListChangedBlocksRequestRequestTypeDef
-):
-    pass
-
 
 ListChangedBlocksResponseTypeDef = TypedDict(
     "ListChangedBlocksResponseTypeDef",
@@ -156,29 +128,15 @@ ListChangedBlocksResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListSnapshotBlocksRequestRequestTypeDef = TypedDict(
-    "_RequiredListSnapshotBlocksRequestRequestTypeDef",
+ListSnapshotBlocksRequestRequestTypeDef = TypedDict(
+    "ListSnapshotBlocksRequestRequestTypeDef",
     {
         "SnapshotId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "StartingBlockIndex": NotRequired[int],
     },
 )
-_OptionalListSnapshotBlocksRequestRequestTypeDef = TypedDict(
-    "_OptionalListSnapshotBlocksRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "StartingBlockIndex": int,
-    },
-    total=False,
-)
-
-
-class ListSnapshotBlocksRequestRequestTypeDef(
-    _RequiredListSnapshotBlocksRequestRequestTypeDef,
-    _OptionalListSnapshotBlocksRequestRequestTypeDef,
-):
-    pass
-
 
 ListSnapshotBlocksResponseTypeDef = TypedDict(
     "ListSnapshotBlocksResponseTypeDef",
@@ -192,8 +150,8 @@ ListSnapshotBlocksResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredPutSnapshotBlockRequestRequestTypeDef = TypedDict(
-    "_RequiredPutSnapshotBlockRequestRequestTypeDef",
+PutSnapshotBlockRequestRequestTypeDef = TypedDict(
+    "PutSnapshotBlockRequestRequestTypeDef",
     {
         "SnapshotId": str,
         "BlockIndex": int,
@@ -201,22 +159,9 @@ _RequiredPutSnapshotBlockRequestRequestTypeDef = TypedDict(
         "DataLength": int,
         "Checksum": str,
         "ChecksumAlgorithm": Literal["SHA256"],
+        "Progress": NotRequired[int],
     },
 )
-_OptionalPutSnapshotBlockRequestRequestTypeDef = TypedDict(
-    "_OptionalPutSnapshotBlockRequestRequestTypeDef",
-    {
-        "Progress": int,
-    },
-    total=False,
-)
-
-
-class PutSnapshotBlockRequestRequestTypeDef(
-    _RequiredPutSnapshotBlockRequestRequestTypeDef, _OptionalPutSnapshotBlockRequestRequestTypeDef
-):
-    pass
-
 
 PutSnapshotBlockResponseTypeDef = TypedDict(
     "PutSnapshotBlockResponseTypeDef",
@@ -238,32 +183,19 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartSnapshotRequestRequestTypeDef = TypedDict(
-    "_RequiredStartSnapshotRequestRequestTypeDef",
+StartSnapshotRequestRequestTypeDef = TypedDict(
+    "StartSnapshotRequestRequestTypeDef",
     {
         "VolumeSize": int,
+        "ParentSnapshotId": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
+        "Description": NotRequired[str],
+        "ClientToken": NotRequired[str],
+        "Encrypted": NotRequired[bool],
+        "KmsKeyArn": NotRequired[str],
+        "Timeout": NotRequired[int],
     },
 )
-_OptionalStartSnapshotRequestRequestTypeDef = TypedDict(
-    "_OptionalStartSnapshotRequestRequestTypeDef",
-    {
-        "ParentSnapshotId": str,
-        "Tags": Sequence["TagTypeDef"],
-        "Description": str,
-        "ClientToken": str,
-        "Encrypted": bool,
-        "KmsKeyArn": str,
-        "Timeout": int,
-    },
-    total=False,
-)
-
-
-class StartSnapshotRequestRequestTypeDef(
-    _RequiredStartSnapshotRequestRequestTypeDef, _OptionalStartSnapshotRequestRequestTypeDef
-):
-    pass
-
 
 StartSnapshotResponseTypeDef = TypedDict(
     "StartSnapshotResponseTypeDef",
@@ -285,8 +217,7 @@ StartSnapshotResponseTypeDef = TypedDict(
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
-        "Key": str,
-        "Value": str,
+        "Key": NotRequired[str],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
